==> vcs-203.6682.86-sources.jar: com/intellij/util/ui/VcsBackgroundTask.java <==
/*
 * Copyright 2000-2007 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.util.ui;

import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.progress.PerformInBackgroundOption;
import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.progress.Task;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.NlsContexts;
import com.intellij.openapi.vcs.AbstractVcsHelper;
import com.intellij.openapi.vcs.VcsException;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * @author yole
 */
public abstract class VcsBackgroundTask<T> extends Task.ConditionalModal {
  private final Collection<? extends T> myItems;
  private final List<VcsException> myExceptions = new ArrayList<>();

  public VcsBackgroundTask(Project project,
                           @NotNull @NlsContexts.ProgressTitle String title,
                           @NotNull final PerformInBackgroundOption backgroundOption,
                           Collection<? extends T> itemsToProcess,
                           boolean canBeCanceled) {
    super(project, title, canBeCanceled, backgroundOption);
    myItems = itemsToProcess;
  }

  public VcsBackgroundTask(Project project,
                           @NotNull @NlsContexts.ProgressTitle String title,
                           @NotNull PerformInBackgroundOption backgroundOption,
                           Collection<? extends T> itemsToProcess) {
    this(project, title, backgroundOption, itemsToProcess, false);
  }

  @Override
  public void run(@NotNull ProgressIndicator indicator) {
    for (T item : myItems) {
      try {
        process(item);
      }
      catch (VcsException ex) {
        if (ApplicationManager.getApplication().isUnitTestMode()) {
          throw new RuntimeException(ex);
        }
        myExceptions.add(ex);
      }
    }
  }

  protected boolean executedOk() {
    return myExceptions.isEmpty();
  }

  @Override
  public void onSuccess() {
    if (!myExceptions.isEmpty()) {
      AbstractVcsHelper.getInstance(myProject).showErrors(myExceptions, myTitle);
    }
  }

  protected abstract void process(T item) throws VcsException;
}

==> vcs-213.5744.248-sources.jar: com/intellij/util/ui/VcsBackgroundTask.java <==
// Copyright 2000-2021 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.util.ui;

import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.progress.PerformInBackgroundOption;
import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.progress.Task;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.NlsContexts;
import com.intellij.openapi.vcs.AbstractVcsHelper;
import com.intellij.openapi.vcs.VcsException;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


public abstract class VcsBackgroundTask<T> extends Task.Backgroundable {
  private final Collection<? extends T> myItems;
  private final List<VcsException> myExceptions = new ArrayList<>();

  public VcsBackgroundTask(Project project,
                           @NotNull @NlsContexts.ProgressTitle String title,
                           Collection<? extends T> itemsToProcess,
                           boolean canBeCanceled) {
    super(project, title, canBeCanceled);
    myItems = itemsToProcess;
  }

  public VcsBackgroundTask(Project project,
                           @NotNull @NlsContexts.ProgressTitle String title,
                           Collection<? extends T> itemsToProcess) {
    this(project, title, itemsToProcess, false);
  }

  @Override
  public void run(@NotNull ProgressIndicator indicator) {
    for (T item : myItems) {
      try {
        process(item);
      }
      catch (VcsException ex) {
        if (ApplicationManager.getApplication().isUnitTestMode()) {
          throw new RuntimeException(ex);
        }
        myExceptions.add(ex);
      }
    }
  }

  protected boolean executedOk() {
    return myExceptions.isEmpty();
  }

  @Override
  public void onSuccess() {
    if (!myExceptions.isEmpty()) {
      AbstractVcsHelper.getInstance(getProject()).showErrors(myExceptions, getTitle());
    }
  }

  protected abstract void process(T item) throws VcsException;
}
